from distutils.core import setup

setup(
         name         = 'print1991',
         version      = '1.0.0',
         py_modules   = ['print1991'],
         author       = 'hfpython',
         author_email = 'hfpython@headfirstlabs.com',
         url          = 'http://www.headfirstlabs.com',
         description  = 'A simple printer of nested lists',

 )
